@@ -353,7 +353,7 @@ class HestiaPi(Sensor):
                 self.off()
 
             # should system boost heating with aux heat?
-            logging.info("Checking temperature rate of change...current rate = {}, min rate = {}".format(self.temperature_rate_of_change, self.minimum_temp_rate_of_change))
+            logging.info(f"Checking temperature rate of change...current rate = {self.temperature_rate_of_change}, min rate = {self.minimum_temp_rate_of_change}, temperature history {self._temperature_history}")
             if self.should_boost():
                 self.boost_heat(HVAC.ON)
 
@@ -413,7 +413,7 @@ class HestiaPi(Sensor):
     def off(self):
         if self._can_change_hvac_state():
             self.set_state(self.mode, HVAC.OFF)
-            self._temperature_history = []
+            self._temperature_history = deque(maxlen=self._temperature_history_period)
         else:
             logging.warn("Did not deactivate {}.".format(self.mode))
 
